SatMAD: Satellite Mission Analysis and Design
=============================================

SatMAD is an open source Python package, aiming at providing the base functionality to solve
satellite mission analysis and design as well as orbital mechanics problems with enough precision and performance
to be used in the design and operation of real satellites. The target audience is academics and amateur satellite
community, including Cubesats (and anyone else who might be interested).

The focus is on good documentation and good test coverage to produce a reliable
flight dynamics library.

Check the source code here: https://github.com/egemenimre/satmad


.. toctree::
   :maxdepth: 2

   about
   getting_started
   user_guide
   examples
   doc_index
   references



Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
